| Title: | Color Palettes from Color Lisa |
|---|---|
| Description: | Contains 128 palettes from Color Lisa. All palettes are based on masterpieces from the worlds greatest artists. For more information, see <http://colorlisa.com/>. |
| Authors: | Tyler Littlefield [aut, cre] (ORCID: <https://orcid.org/0000-0002-6020-1125>) |
| Maintainer: | Tyler Littlefield <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-28 10:39:52 UTC |
| Source: | https://github.com/tylerlittlefield/lisa |
A table containing various information about each palette.
artworkartwork
A data frame with 128 rows and 3 variables:
name of artist
name of artwork
name of the palette
hex color codes
url for artwork info
a tibble
Source: http://colorlisa.com/
A list containing all available palettes (128) and their attributes (class, artist name and the name of the artwork).
lisalisa
An object of class list of length 128.
Source: http://colorlisa.com/
Call or modify lisa palettes
lisa_palette(name, n, type = c("discrete", "continuous"))lisa_palette(name, n, type = c("discrete", "continuous"))
name |
Name of desired palette. See |
n |
Number of colors desired. |
type |
Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colors. |
A vector of colors.
lisa_palette(name = "Prince", n = 10, type = "continuous") lisa_palette("PabloPicasso", 2, "discrete")lisa_palette(name = "Prince", n = 10, type = "continuous") lisa_palette("PabloPicasso", 2, "discrete")